package ru.mnogoblog;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.Input;
import com.badlogic.gdx.Screen;
import com.badlogic.gdx.audio.Music;
import com.badlogic.gdx.audio.Sound;
import com.badlogic.gdx.graphics.GL20;
import com.badlogic.gdx.graphics.OrthographicCamera;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.math.MathUtils;
import com.badlogic.gdx.math.Rectangle;
import com.badlogic.gdx.math.Vector3;
import com.badlogic.gdx.utils.Array;
import com.badlogic.gdx.utils.TimeUtils;

import java.util.Iterator;

public class PonyGame3 implements Screen {

	final Drop game;
	OrthographicCamera camera;
	Texture dropImage;
	Texture myPony;
	Texture bucketImage;
	Sound dropSound;
	Music rainMusic;
	Rectangle bucket;
	Vector3 touchPos;
	Array<Rectangle> raindrops;
	long lastDropTime;
	static int dropsGatchered;
	static int dropsGatchered2;
	String dropString;
	public static Texture backgroundTexture;
	float timer = 0f;
	int time = 0;




	public PonyGame3 (final Drop gam) {
		this.game = gam;

		camera = new OrthographicCamera();
		camera.setToOrtho(false, 800, 480);

		touchPos = new Vector3();

		dropImage = new Texture("apple.png");
		myPony = new Texture("pony.png");
		bucketImage = new Texture("bucket2.png");
		backgroundTexture = new Texture("bg.png");

		dropSound = Gdx.audio.newSound(Gdx.files.internal("mpput.mp3"));
		rainMusic = Gdx.audio.newMusic(Gdx.files.internal("ponyfongame.mp3"));

		rainMusic.setLooping(true);
		rainMusic.play();

		bucket = new Rectangle();
		bucket.x = 800 / 2 - 64 / 2;
		bucket.y = 20;
		bucket.width = 64;
		bucket.height = 64;

		raindrops = new Array<Rectangle>();
		spawnRaindrop();

	}

	private void spawnRaindrop(){
		Rectangle raindrop = new Rectangle();
		raindrop.x = MathUtils.random(0, 800-64);
		raindrop.y = 480;
		raindrop.width = 64;
		raindrop.height = 64;
		raindrops.add(raindrop);
		lastDropTime = TimeUtils.nanoTime();
	}

	@Override
	public void render (float delta) {



		Gdx.gl.glClearColor(1, 1, 1, 1);
		Gdx.gl.glClear(GL20.GL_COLOR_BUFFER_BIT);

		camera.update();

		game.batch.setProjectionMatrix(camera.combined);
		game.batch.begin();
		game.batch.draw(backgroundTexture, 0, 0, 800, 480);
		game.batch.draw(dropImage, 0,440,64,64);

		game.myfont.draw(game.batch, "Время:" + (6100-time)/100, 350, 460);
		game.myfont.draw(game.batch, ": " + dropsGatchered, 60, 460);
		game.batch.draw(bucketImage, bucket.x, bucket.y);

		for (Rectangle raindrop: raindrops){
			game.batch.draw(dropImage, raindrop.x, raindrop.y);
		}
		game.batch.draw(myPony, 0,0,200,100);
		game.batch.end();

		timer = delta;
		if (timer >= 0) {

			time++;

		}

		if (time>6000) {
			game.setScreen(new GameOverScreen(game));
			dropsGatchered2=dropsGatchered;
			dropsGatchered=0;
			dispose();
		}

		if(Gdx.input.isTouched()){
			touchPos.set(Gdx.input.getX(), Gdx.input.getY(), 0);
			if (touchPos.x<400) bucket.x -= 200 * Gdx.graphics.getDeltaTime();
			if(touchPos.x>400) bucket.x += 200 * Gdx.graphics.getDeltaTime();
		}

		if(Gdx.input.isKeyPressed(Input.Keys.LEFT)) bucket.x -= 200 * Gdx.graphics.getDeltaTime();
		if(Gdx.input.isKeyPressed(Input.Keys.RIGHT)) bucket.x += 200 * Gdx.graphics.getDeltaTime();

		if (bucket.x < 0) bucket.x = 0;
		if (bucket.x > 800 - 64) bucket.x = 800 - 64;

		if (TimeUtils.nanoTime() - lastDropTime > 1000000000) spawnRaindrop();

		Iterator<Rectangle> iter = raindrops.iterator();
		while (iter.hasNext()){
			Rectangle raindrop = iter.next();
			raindrop.y -= 200 * Gdx.graphics.getDeltaTime();
			if (raindrop.y + 64 < 0) iter.remove();
			if (raindrop.overlaps(bucket)){
				dropsGatchered++;
				dropSound.play();
				iter.remove();
			}

		}
	}

	@Override
	public void resize(int width, int height) {

	}

	@Override
	public void pause() {

	}

	@Override
	public void resume() {

	}

	@Override
	public void hide() {

	}

	@Override
	public void dispose() {
		dropImage.dispose();
		bucketImage.dispose();
		dropSound.dispose();
		rainMusic.dispose();
	}

	@Override
	public void show() {
		rainMusic.play();
	}
}

